==> breeze-5.0.95.tar.xz: breeze-5.0.95/kstyle/breezepropertynames.h <==
#ifndef breezepropertynames_h
#define breezepropertynames_h

/*************************************************************************
 * Copyright (C) 2014 by Hugo Pereira Da Costa <hugo.pereira@free.fr>    *
 *                                                                       *
 * This program is free software; you can redistribute it and/or modify  *
 * it under the terms of the GNU General Public License as published by  *
 * the Free Software Foundation; either version 2 of the License, or     *
 * (at your option) any later version.                                   *
 *                                                                       *
 * This program is distributed in the hope that it will be useful,       *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 * GNU General Public License for more details.                          *
 *                                                                       *
 * You should have received a copy of the GNU General Public License     *
 * along with this program; if not, write to the                         *
 * Free Software Foundation, Inc.,                                       *
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 *************************************************************************/


namespace Breeze
{

    struct PropertyNames
    {

        static const char* const noAnimations;
        static const char* const noWindowGrab;
        static const char* const netWMForceShadow;
        static const char* const netWMSkipShadow;
        static const char* const sidePanelView;
        static const char* const toolButtonAlignment;
    };

}

#endif

==> breeze-5.1.95.tar.xz: breeze-5.1.95/kstyle/breezepropertynames.h <==
#ifndef breezepropertynames_h
#define breezepropertynames_h

/*************************************************************************
 * Copyright (C) 2014 by Hugo Pereira Da Costa <hugo.pereira@free.fr>    *
 *                                                                       *
 * This program is free software; you can redistribute it and/or modify  *
 * it under the terms of the GNU General Public License as published by  *
 * the Free Software Foundation; either version 2 of the License, or     *
 * (at your option) any later version.                                   *
 *                                                                       *
 * This program is distributed in the hope that it will be useful,       *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 * GNU General Public License for more details.                          *
 *                                                                       *
 * You should have received a copy of the GNU General Public License     *
 * along with this program; if not, write to the                         *
 * Free Software Foundation, Inc.,                                       *
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 *************************************************************************/


namespace Breeze
{

    struct PropertyNames
    {

        static const char noAnimations[];
        static const char noWindowGrab[];
        static const char netWMForceShadow[];
        static const char netWMSkipShadow[];
        static const char sidePanelView[];
        static const char toolButtonAlignment[];
    };

}

#endif
